@@ -30,62 +30,61 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-'''
-This tool changes the priority from some SRV records from 0 to 100
-'''
+"""This tool changes the priority from some SRV records from 0 to 100"""
 
 import univention.admin
-import univention.admin.uldap
-import univention.admin.modules
 import univention.admin.handlers.dns.forward_zone
 import univention.admin.handlers.dns.srv_record
+import univention.admin.modules
+import univention.admin.uldap
 import univention.config_registry
 
+
 PRIORITY_NEW = '100'
 PRIORITY_OLD = '0'
 
 SRV_RECORDS = [
-	['ldap', 'tcp'],
-	['kerberos', 'tcp'],
-	['kerberos', 'udp'],
-	['kerberos-adm', 'tcp'],
-	['kpasswd', 'tcp'],
-	['kpasswd', 'udp'],
+    ['ldap', 'tcp'],
+    ['kerberos', 'tcp'],
+    ['kerberos', 'udp'],
+    ['kerberos-adm', 'tcp'],
+    ['kpasswd', 'tcp'],
+    ['kpasswd', 'udp'],
 ]
 
 
 def main():
-	# type: () -> None
-	univention.admin.modules.update()
+    # type: () -> None
+    univention.admin.modules.update()
 
-	configRegistry = univention.config_registry.ConfigRegistry()
-	configRegistry.load()
+    configRegistry = univention.config_registry.ConfigRegistry()
+    configRegistry.load()
 
-	lo, position = univention.admin.uldap.getAdminConnection()
-	forward_module = univention.admin.modules.get('dns/forward_zone')
-	forward_zones = univention.admin.modules.lookup(forward_module, None, lo, scope='sub', superordinate=None, base=configRegistry.get('ldap_base'))
+    lo, position = univention.admin.uldap.getAdminConnection()
+    forward_module = univention.admin.modules.get('dns/forward_zone')
+    forward_zones = univention.admin.modules.lookup(forward_module, None, lo, scope='sub', superordinate=None, base=configRegistry.get('ldap_base'))
 
-	srv_module = univention.admin.modules.get('dns/srv_record')
-	for forward_zone in forward_zones:
-		srv_records = univention.admin.modules.lookup(srv_module, None, lo, scope='sub', superordinate=forward_zone, base=configRegistry.get('ldap_base'))
+    srv_module = univention.admin.modules.get('dns/srv_record')
+    for forward_zone in forward_zones:
+        srv_records = univention.admin.modules.lookup(srv_module, None, lo, scope='sub', superordinate=forward_zone, base=configRegistry.get('ldap_base'))
 
-		for srv_record in srv_records:
-			name = srv_record.get('name')
-			modify = False
-			if name in SRV_RECORDS:
-				for location in srv_record['location']:
-					if len(location) > 1 and location[1] == PRIORITY_OLD:
-						location[1] = PRIORITY_NEW
-						modify = True
+        for srv_record in srv_records:
+            name = srv_record.get('name')
+            modify = False
+            if name in SRV_RECORDS:
+                for location in srv_record['location']:
+                    if len(location) > 1 and location[1] == PRIORITY_OLD:
+                        location[1] = PRIORITY_NEW
+                        modify = True
 
-				if modify:
-					# make SRV records uniq
-					srv_record['location'] = list(set(srv_record['location']))
+                if modify:
+                    # make SRV records uniq
+                    srv_record['location'] = list(set(srv_record['location']))
 
-					# Change the objects
-					print('Modify: %s' % srv_record.dn)
-					srv_record.modify()
+                    # Change the objects
+                    print('Modify: %s' % srv_record.dn)
+                    srv_record.modify()
 
 
 if __name__ == "__main__":
-	main()
+    main()
